######################
#### Daniel J. Hopkins
#### Georgetown University
#### October 29, 2012
####
#### Replication code for:
#### Whose Economy?  Perceptions of Economic Performance During Unequal Growth
#### Public Opinion Quarterly, 2012.  76(1):50-70.
####
#### The Michigan Survey of Consumer Attitudes data set is available from ICPSR.
#### With the written permission of ICPSR, I will provide the full, merged data set to any interested party.
#### The publicly available economic indicators are contained in a corresponding .zip file, 
#### economicindicator.zip
#### 
######################

#### load libraries
library(arm)
library(xtable)
library(lme4)

#setwd("C:/Users/dh335/Documents/consumer/fulldata/")
#load("C:/Users/dh335/Documents/consumer/fulldata/fulldata121910.Rdata")
#load("/Users/ameliawhitehead/Desktop/hopkins stuff/fulldata122410.Rdata")
#### load data set
load("/Users/danielhopkins/Dropbox/consumer/replication/fulldata122410.Rdata")

#### recode variables
dtam8$yrmnth2 <- dtam8$YEAR + (dtam8$MONTH+1)/12
dtam8$black <- (dtam8$RACE==2)*1
dtam8$hisp <- (dtam8$RACE==3)*1
dtam8$amindian <- (dtam8$RACE==4)*1
dtam8$asian <- (dtam8$RACE==5)*1

dtam8$educ <- NA
dtam8$educ[dtam8$EDUC==1] <- 8
dtam8$educ[dtam8$EDUC==2] <- 10
dtam8$educ[dtam8$EDUC==3] <- 12
dtam8$educ[dtam8$EDUC==4] <- 13
dtam8$educ[dtam8$EDUC==5] <- 14
dtam8$educ[dtam8$EDUC==6] <- 16

dtam8$married <- (dtam8$MARRY==1)*1 
dtam8$pago3 <- dtam8$PAGO3
dtam8$bago3 <- dtam8$BAGO3
dtam8$bago4 <- dtam8$bago3+6
dtam8$yrmnth2 <- dtam8$YEAR+(dtam8$MONTH+1)/12
dtam8$natlunemp1 <- dtam8$UNEMP1
dtam8$gas.month1 <- dtam8$RealGas1
dtam8$oilprice1 <- dtam8$RealOil1
dtam8$age <- dtam8$AGE

### subset poor, middle, wealthy
dtap <- dtam8[dtam8$incomeq2bot==1 & ! dtam8$incomeq2bot %in% c(NA),]
dtar <- dtam8[dtam8$incomeq2top==1 & ! dtam8$incomeq2top %in% c(NA),]
dtam <- dtam8[dtam8$incomeq2mid==1 & ! dtam8$incomeq2top %in% c(NA),]

dtap$age2 <- dtap$age/100
dtar$age2 <- dtar$age/100
dtam$age2 <- dtam$age/100

dtap$income2b <- dtap$income2a/1000000
dtar$income2b <- dtar$income2a/1000000
dtam$income2b <- dtam$income2a/1000000



#### Table 1:
loutp3 <- lmer(bago4 ~ Top.yr.pct+Fourth.yr.pct+Third.yr.pct+Second.yr.pct+Lowest.yr.pct+natlunemp1+RealGas1+oilprice1+yrmnth2+I((P1-P2)/P2)+income2b+educ+black+hisp+amindian+asian+married+age2+I(age2^2)+(1|YEAR),data=dtap)

loutr3 <- lmer(bago4 ~ Top.yr.pct+Fourth.yr.pct+Third.yr.pct+Second.yr.pct+Lowest.yr.pct+natlunemp1+RealGas1+oilprice1+yrmnth2+I((P1-P2)/P2)+income2b+educ+black+hisp+amindian+asian+married+age2+I(age2^2)+(1|YEAR),data=dtar)

loutm3 <- lmer(bago4 ~ Top.yr.pct+Fourth.yr.pct+Third.yr.pct+Second.yr.pct+Lowest.yr.pct+natlunemp1+RealGas1+oilprice1+yrmnth2+I((P1-P2)/P2)+income2b+educ+black+hisp+amindian+asian+married+age2+I(age2^2)+(1|YEAR),data=dtam)

c1 <- unlist(coef(loutp3)$YEAR[1,])
c2 <- c(se.coef(loutp3)$fixef)

c3 <- unlist(coef(loutr3)$YEAR[1,])
c4 <- c(se.coef(loutr3)$fixef)

c5 <- unlist(coef(loutm3)$YEAR[1,])
c6 <- c(se.coef(loutm3)$fixef)

library(xtable)
xtable(cbind(c1,c2,c5,c6,c3,c4),digits=c(0,3,3,3,3,3,3))


#### Figure 2

library(xtable)
library(combinat)

loutp1 <- lmer(bago3 ~ Top.yr.pct+Lowest.yr.pct+(1|YEAR),data=dtap)
summary(loutp1)

loutr1 <- lmer(bago3 ~ Top.yr.pct+Lowest.yr.pct+(1|YEAR),data=dtar)
summary(loutr1)

loutm1 <- lmer(bago3 ~ Top.yr.pct+Lowest.yr.pct+(1|YEAR),data=dtam)
summary(loutm1)

loutp2 <- lmer(bago3 ~ Top.yr.pct+Lowest.yr.pct+natlunemp1+I((P1-P2)/P2)+(1|YEAR),data=dtap)
summary(loutp2)

loutr2 <- lmer(bago3 ~ Top.yr.pct+Lowest.yr.pct+natlunemp1+I((P1-P2)/P2)+(1|YEAR),data=dtar)
summary(loutr2)

loutm2 <- lmer(bago3 ~ Top.yr.pct+Lowest.yr.pct+natlunemp1+I((P1-P2)/P2)+(1|YEAR),data=dtam)
summary(loutm2)

#+gas.month1+oilprice1
loutp3 <- lmer(bago3 ~ Top.yr.pct+Lowest.yr.pct+natlunemp1+I((P1-P2)/P2)+income2a+educ+black+hisp+amindian+asian+married+age+I(age^2)+(1|YEAR),data=dtap)
summary(loutp3)

loutr3 <- lmer(bago3 ~ Top.yr.pct+Lowest.yr.pct+natlunemp1+I((P1-P2)/P2)+income2a+educ+black+hisp+amindian+asian+married+age+I(age^2)+(1|YEAR),data=dtar)
summary(loutr3)

loutm3 <- lmer(bago3 ~ Top.yr.pct+Lowest.yr.pct+natlunemp1+I((P1-P2)/P2)+income2a+educ+black+hisp+amindian+asian+married+age+I(age^2)+(1|YEAR),data=dtam)
summary(loutm3)

library(arm)


rmat3 <- rmat2 <- rmat <- matrix(NA,3,6)
for(i in 1:3){
	txt <- paste("loutp <- loutp",i,sep="")
	eval(parse(text=txt))

	### matrix for poor
	rmat[i,1] <- coef(loutp)$YEAR[1,2]
	rmat[i,2] <- coef(loutp)$YEAR[1,2]-1.96*se.coef(loutp)$fixef[2]
	rmat[i,3] <- coef(loutp)$YEAR[1,2]+1.96*se.coef(loutp)$fixef[2]
	rmat[i,4] <- coef(loutp)$YEAR[1,3]
	rmat[i,5] <- coef(loutp)$YEAR[1,3]-1.96*se.coef(loutp)$fixef[3]
	rmat[i,6] <- coef(loutp)$YEAR[1,3]+1.96*se.coef(loutp)$fixef[3]

	txt <- paste("loutr <- loutr",i,sep="")
	eval(parse(text=txt))

	### matrix for rich
	rmat2[i,1] <- coef(loutr)$YEAR[1,2]
	rmat2[i,2] <- coef(loutr)$YEAR[1,2]-1.96*se.coef(loutr)$fixef[2]
	rmat2[i,3] <- coef(loutr)$YEAR[1,2]+1.96*se.coef(loutr)$fixef[2]
	rmat2[i,4] <- coef(loutr)$YEAR[1,3]
	rmat2[i,5] <- coef(loutr)$YEAR[1,3]-1.96*se.coef(loutr)$fixef[3]
	rmat2[i,6] <- coef(loutr)$YEAR[1,3]+1.96*se.coef(loutr)$fixef[3]

	### matrix for middle
	txt <- paste("loutm <- loutm",i,sep="")
	eval(parse(text=txt))

	rmat3[i,1] <- coef(loutm)$YEAR[1,2]
	rmat3[i,2] <- coef(loutm)$YEAR[1,2]-1.96*se.coef(loutm)$fixef[2]
	rmat3[i,3] <- coef(loutm)$YEAR[1,2]+1.96*se.coef(loutm)$fixef[2]
	rmat3[i,4] <- coef(loutm)$YEAR[1,3]
	rmat3[i,5] <- coef(loutm)$YEAR[1,3]-1.96*se.coef(loutm)$fixef[3]
	rmat3[i,6] <- coef(loutm)$YEAR[1,3]+1.96*se.coef(loutm)$fixef[3]

}
mn <- min(c(0,rmat[,c(1:6)],rmat2[,c(1:6)]))
mx <- max(c(rmat[,c(1:6)],rmat2[,c(1:6)]))

X1 <- rnorm(10000,mean=rmat[3,1],sd=((rmat[3,1]-rmat[3,2])/1.96))
X2 <- rnorm(10000,mean=rmat[3,4],sd=((rmat[3,4]-rmat[3,5])/1.96))
sum(X1 > X2)/10000

X3 <- rnorm(10000,mean=rmat2[3,1],sd=((rmat2[3,1]-rmat2[3,2])/1.96))
X4 <- rnorm(10000,mean=rmat2[3,4],sd=((rmat2[3,4]-rmat2[3,5])/1.96))
sum(X3 > X4)/10000

X5 <- rnorm(10000,mean=rmat3[3,1],sd=((rmat3[3,1]-rmat3[3,2])/1.96))
X6 <- rnorm(10000,mean=rmat3[3,4],sd=((rmat3[3,4]-rmat3[3,5])/1.96))
sum(X5 > X6)/10000

colvec <- c("grey47","grey75","grey85")
#colvec <- c(217,260,239)
#pdf("wealthypoordens7.pdf",width=10)
#postscript("wealthypoordens7.eps")
MM <- 100000
par(mfcol=c(1,3))
par(pty="s")
#draws <- rnorm(MM,mean=rmat[i,1],sd=((rmat[i,1]-rmat[i,2])/1.96))
draws <- rnorm(MM,mean=rmat[i,1],sd=((rmat[i,1]-rmat[i,2])/1.96))
plot(type="n",density(draws),xlim=c(mn,mx),xlab="Coefficient",main="Bottom Quarter \n of Income Distribution",ylab="",yaxt="n",lty=i,cex.main=1.5)

#### poor

par(new=T)
for(i in 1:3){
	draws <- rnorm(MM,mean=rmat[i,1],sd=((rmat[i,1]-rmat[i,2])/1.96))
	plot(density(draws),xlim=c(mn,mx),xlab="",main="",ylab="",yaxt="n",lty=i,xaxt="n")
	dens <- density(draws)
	x1 <- 1 
	x2 <- 512
	xvec <- c(dens$x[c(x1,x1:x2,x2)])
	yvec <- c(0, dens$y[c(x1:x2)], 0)
	polygon(x=xvec, y=yvec,col=colvec[i])
	par(new=T)
	plot(density(draws),xlim=c(mn,mx),xlab="",main="",ylab="",yaxt="n",lty=i,xaxt="n")
	par(new=T)
}

par(new=T)
for(i in 1:3){
	draws <- rnorm(MM,mean=rmat[i,4],sd=((rmat[i,4]-rmat[i,5])/1.96))
	plot(density(draws),xlim=c(mn,mx),xlab="",main="",ylab="",yaxt="n",xaxt="n",col=colvec[i],lwd=2)
	dens <- density(draws)
	x1 <- 1 
	x2 <- 512
	xvec <- c(dens$x[c(x1,x1:x2,x2)])
	yvec <- c(0, dens$y[c(x1:x2)], 0)
	#polygon(x=xvec, y=yvec,col="white")
	if(i %in% c(1,2)){
		par(new=T)
	}
}
text(x=rmat[i,1]-2,y=.05,"Top \n Growth",cex=1.25)
text(x=rmat[i,4]+5,y=.05,"Bottom \n Growth",col="black",cex=1.25)

#### middle

draws <- rnorm(MM,mean=rmat3[i,1],sd=((rmat3[i,1]-rmat3[i,2])/1.96))
plot(type="n",density(draws),xlim=c(mn,mx),xlab="Coefficient",main="Middle 30 Percent \n of Income Distribution",ylab="",yaxt="n",lty=i,cex.main=1.5)
par(new=T)
for(i in 1:3){
	draws <- rnorm(MM,mean=rmat3[i,1],sd=((rmat3[i,1]-rmat3[i,2])/1.96))
	plot(density(draws),xlim=c(mn,mx),xlab="",main="",ylab="",yaxt="n",lty=i,xaxt="n")
	dens <- density(draws)
	x1 <- 1 
	x2 <- 512
	xvec <- c(dens$x[c(x1,x1:x2,x2)])
	yvec <- c(0, dens$y[c(x1:x2)], 0)
	polygon(x=xvec, y=yvec,col=colvec[i])
	par(new=T)
	plot(density(draws),xlim=c(mn,mx),xlab="",main="",ylab="",yaxt="n",lty=i,xaxt="n")
	par(new=T)
}

par(new=T)
for(i in 1:3){
	draws <- rnorm(MM,mean=rmat3[i,4],sd=((rmat3[i,4]-rmat3[i,5])/1.96))
	plot(density(draws),xlim=c(mn,mx),xlab="",main="",ylab="",yaxt="n",xaxt="n",col=colvec[i],lwd=2)
	dens <- density(draws)
	x1 <- 1 
	x2 <- 512
	xvec <- c(dens$x[c(x1,x1:x2,x2)])
	yvec <- c(0, dens$y[c(x1:x2)], 0)
	#polygon(x=xvec, y=yvec,col="white")
	if(i %in% c(1,2)){
		par(new=T)
	}
}
text(x=rmat3[i,1]-2,y=.05,"Top \n Growth",cex=1.25)
text(x=rmat3[i,4]+5,y=.05,"Bottom \n Growth",col="black",cex=1.25)

#### wealthy

plot(density(draws),xlim=c(mn,mx),xlab="Coefficient",main="Top Quarter \n of Income Distribution",ylab="",yaxt="n",lty=i,type="n",cex.main=1.5)
par(new=T)
for(i in 1:3){
	draws <- rnorm(MM,mean=rmat2[i,1],sd=((rmat2[i,1]-rmat2[i,2])/1.96))
	plot(density(draws),xlim=c(mn,mx),xlab="",main="",ylab="",yaxt="n",xaxt="n",col="black")
	dens <- density(draws)
	x1 <- 1 
	x2 <- 512
	xvec <- c(dens$x[c(x1,x1:x2,x2)])
	yvec <- c(0, dens$y[c(x1:x2)], 0)
	polygon(x=xvec, y=yvec,col=colvec[i])
	par(new=T)
}

par(new=T)
for(i in 1:3){
	draws <- rnorm(MM,mean=rmat2[i,4],sd=((rmat2[i,4]-rmat2[i,5])/1.96))
	plot(density(draws),xlim=c(mn,mx),xlab="",main="",ylab="",yaxt="n",xaxt="n",lwd=2,col=colvec[i])
	dens <- density(draws)
	x1 <- 1 
	x2 <- 512
	xvec <- c(dens$x[c(x1,x1:x2,x2)])
	yvec <- c(0, dens$y[c(x1:x2)], 0)
	#polygon(x=xvec, y=yvec,col="white")
	if(i %in% c(1,2)){
		par(new=T)
	}
}
text(x=rmat2[i,1],y=.0275,"Top \n Growth",cex=1.25)
text(x=rmat2[i,4]+2,y=.0275,"Bottom \n Growth",col="black",cex=1.25)

#dev.off()

#### Table 2A

loutr8 <- lmer(bago3 ~ Top.adj+Lowest.adj+natlunemp1+yrmnth2+I((P1-P2)/P2)+income2a+educ+black+hisp+amindian+asian+married+age+I(age^2)+(1|yrmnth2),data=dtar)
loutp8 <- lmer(bago3 ~ Top.adj+Lowest.adj+natlunemp1+yrmnth2+I((P1-P2)/P2)+income2a+educ+black+hisp+amindian+asian+married+age+I(age^2)+(1|yrmnth2),data=dtap)
loutm8 <- lmer(bago3 ~ Top.adj+Lowest.adj+natlunemp1+yrmnth2+I((P1-P2)/P2)+income2a+educ+black+hisp+amindian+asian+married+age+I(age^2)+(1|yrmnth2),data=dtam)

#)+gas.month1+oilprice1

#### subset out months
dtapj <- dtap[dtap$MONTH==12,]
dtarj <- dtar[dtar$MONTH==12,]

loutp7 <- lmer(bago4 ~ Top.yr.pct+Lowest.yr.pct+natlunemp1+yrmnth2+I((P1-P2)/P2)+income2b+educ+black+hisp+amindian+asian+married+age+I(age^2)+(1|YEAR),data=dtapj)

loutr7 <- lmer(bago4 ~ Top.yr.pct+Lowest.yr.pct+natlunemp1+yrmnth2+I((P1-P2)/P2)+income2b+educ+black+hisp+amindian+asian+married+age+I(age^2)+(1|YEAR),data=dtarj)

V1 <- unlist(coef(loutp7)$YEAR[1,])
V2 <- se.coef(loutp7)$fixef
V3 <- unlist(coef(loutr7)$YEAR[1,])
V4 <- se.coef(loutr7)$fixef

X1 <- cbind(V1,V2,V3,V4)
xtable(X1,digits=c(0,3,3,3,3))